configExists method
Check if config file exists in current directory.
Returns true if the configuration file exists, false otherwise.
Implementation
bool configExists() {
return File(configFileName).existsSync();
}
Check if config file exists in current directory.
Returns true if the configuration file exists, false otherwise.
bool configExists() {
return File(configFileName).existsSync();
}