clearAndPrint static method
Clear line and print new message with proper spacing
Implementation
static void clearAndPrint(String message) {
clearLine();
stdout.writeln(message);
}
Clear line and print new message with proper spacing
static void clearAndPrint(String message) {
clearLine();
stdout.writeln(message);
}