ConfigService class
Service for managing configuration files.
Handles creation, loading, and validation of the AI Translation Generator configuration file (ai_translation_generator.yaml).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
configExists(
) → bool - Check if config file exists in current directory.
-
createDefaultConfig(
) → Future< void> - Create default configuration file
-
getCurrentDirectory(
) → String - Get the current working directory
-
loadConfig(
) → Future< TranslationConfig> - Load configuration from file
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateConfig(
) → Future< bool> - Validate configuration format and content
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- configFileName → const String